@@ -59,6 +59,7 @@ error "gperf generated tables don't work with this execution character set. Plea
 #include <string.h>
 #include <stdlib.h>
 #include <assert.h>
+#include <stdbool.h>
 #include "export.h"
 #include "types.e"
 
@@ -67,7 +68,7 @@ EXPORTDEF(MAXNAMELEN)
 
 EXPORT typedef struct _ElementType {
   string name;
-  Boolean mixed, empty, stag, etag, pre, break_before, break_after;
+  bool mixed, empty, stag, etag, pre, break_before, break_after;
   string parents[60];
 } ElementType;
 
@@ -153,197 +154,197 @@ lookup_element (str, len)
   static const ElementType wordlist[] =
     {
       {""},
-#line 55 "dtd.hash"
+#line 56 "dtd.hash"
       {"a",		1, 0, 1, 1, 0, 0, 0, {"p", "abbr", "acronym", "address", "b", "bdo", "big", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 129 "dtd.hash"
+#line 130 "dtd.hash"
       {"tt",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""},
-#line 120 "dtd.hash"
+#line 121 "dtd.hash"
       {"table",		0, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
       {""},
-#line 78 "dtd.hash"
+#line 79 "dtd.hash"
       {"dt",		1, 0, 1, 0, 0, 1, 1, {"dl", NULL}},
-#line 123 "dtd.hash"
+#line 124 "dtd.hash"
       {"textarea",	1, 0, 1, 1, 1, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""},
-#line 54 "dtd.hash"
+#line 55 "dtd.hash"
       {"%data",	1, 0, 1, 0, 0, 0, 0, {"p", NULL}},
-#line 110 "dtd.hash"
+#line 111 "dtd.hash"
       {"q",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 122 "dtd.hash"
+#line 123 "dtd.hash"
       {"td",		1, 0, 1, 0, 0, 1, 1, {"tr", NULL}},
       {""}, {""},
-#line 117 "dtd.hash"
-      {"style",		1, 0, 1, 1, 1, 1, 1, {"head", NULL}},
-#line 113 "dtd.hash"
+#line 118 "dtd.hash"
+      {"style",		1, 0, 1, 1, 1, 1, 0, {"head", NULL}},
+#line 114 "dtd.hash"
       {"select",		0, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 73 "dtd.hash"
-      {"dd",		1, 0, 1, 0, 0, 1, 1, {"dl", NULL}},
 #line 74 "dtd.hash"
+      {"dd",		1, 0, 1, 0, 0, 1, 1, {"dl", NULL}},
+#line 75 "dtd.hash"
       {"del",		1, 0, 1, 1, 0, 0, 0, {"p", "body", "a", "abbr", "acronym", "address", "b", "bdo", "big", "blockquote", "button", "caption", "cite", "code", "colgroup", "dd", "dfn", "div", "dl", "dt", "em", "fieldset", "form", "h1", "h2", "h3", "h4", "h5", "h6", "i", "kbd", "label", "legend", "li", "map", "noscript", "object", "ol", "optgroup", "option", "pre", "q", "samp", "select", "small", "span", "strong", "sub", "sup", "table", "tbody", "td", "textarea", "tfoot", "th", "thead", "tt", "ul", "var", NULL}},
-#line 101 "dtd.hash"
-      {"meta",		0, 1, 1, 0, 0, 0, 1, {"head", NULL}},
+#line 102 "dtd.hash"
+      {"meta",		0, 1, 1, 0, 0, 1, 0, {"head", NULL}},
       {""},
-#line 97 "dtd.hash"
+#line 98 "dtd.hash"
       {"legend",		1, 0, 1, 1, 0, 1, 1, {"fieldset", NULL}},
-#line 58 "dtd.hash"
+#line 59 "dtd.hash"
       {"address",	1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
       {""}, {""},
-#line 96 "dtd.hash"
+#line 97 "dtd.hash"
       {"label",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""},
-#line 77 "dtd.hash"
+#line 78 "dtd.hash"
       {"dl",		0, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
       {""},
-#line 111 "dtd.hash"
+#line 112 "dtd.hash"
       {"samp",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 127 "dtd.hash"
+#line 128 "dtd.hash"
       {"title",		1, 0, 1, 1, 0, 1, 1, {"head", NULL}},
-#line 107 "dtd.hash"
+#line 108 "dtd.hash"
       {"p",		1, 0, 1, 0, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
-#line 79 "dtd.hash"
+#line 80 "dtd.hash"
       {"em",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 100 "dtd.hash"
+#line 101 "dtd.hash"
       {"map",		0, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""},
-#line 108 "dtd.hash"
+#line 109 "dtd.hash"
       {"param",		0, 1, 1, 0, 0, 1, 1, {"object", NULL}},
-#line 112 "dtd.hash"
-      {"script",		1, 0, 1, 1, 1, 0, 1, {"p", "body", "a", "abbr", "acronym", "address", "b", "bdo", "big", "blockquote", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "form", "h1", "h2", "h3", "h4", "h5", "h6", "head", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 104 "dtd.hash"
+#line 113 "dtd.hash"
+      {"script",		1, 0, 1, 1, 1, 1, 0, {"p", "body", "a", "abbr", "acronym", "address", "b", "bdo", "big", "blockquote", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "form", "h1", "h2", "h3", "h4", "h5", "h6", "head", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
+#line 105 "dtd.hash"
       {"ol",		0, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
       {""},
-#line 70 "dtd.hash"
+#line 71 "dtd.hash"
       {"code",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 114 "dtd.hash"
+#line 115 "dtd.hash"
       {"small",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""},
-#line 57 "dtd.hash"
+#line 58 "dtd.hash"
       {"acronym",	1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""}, {""},
-#line 116 "dtd.hash"
+#line 117 "dtd.hash"
       {"strong",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""},
-#line 71 "dtd.hash"
+#line 72 "dtd.hash"
       {"col",		0, 1, 1, 0, 0, 0, 0, {"colgroup", "table", NULL}},
-#line 69 "dtd.hash"
+#line 70 "dtd.hash"
       {"cite",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""},
-#line 91 "dtd.hash"
+#line 92 "dtd.hash"
       {"i",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""},
-#line 105 "dtd.hash"
+#line 106 "dtd.hash"
       {"optgroup",	0, 0, 1, 1, 0, 1, 1, {"select", NULL}},
-#line 59 "dtd.hash"
+#line 60 "dtd.hash"
       {"area",		0, 1, 1, 0, 0, 0, 0, {"map", NULL}},
       {""}, {""}, {""},
-#line 72 "dtd.hash"
+#line 73 "dtd.hash"
       {"colgroup",	0, 0, 1, 1, 0, 1, 1, {"table", NULL}},
       {""}, {""}, {""},
-#line 98 "dtd.hash"
+#line 99 "dtd.hash"
       {"li",		1, 0, 1, 0, 0, 1, 1, {"ul", "ol", NULL}},
-#line 102 "dtd.hash"
+#line 103 "dtd.hash"
       {"noscript",	0, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
-#line 61 "dtd.hash"
+#line 62 "dtd.hash"
       {"base",		0, 1, 1, 0, 0, 1, 1, {"head", NULL}},
-#line 124 "dtd.hash"
+#line 125 "dtd.hash"
       {"tfoot",		0, 0, 1, 0, 0, 1, 1, {"table", NULL}},
       {""},
-#line 68 "dtd.hash"
+#line 69 "dtd.hash"
       {"caption",	1, 0, 1, 1, 0, 1, 1, {"table", NULL}},
-#line 109 "dtd.hash"
+#line 110 "dtd.hash"
       {"pre",		1, 0, 1, 1, 1, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
-#line 115 "dtd.hash"
+#line 116 "dtd.hash"
       {"span",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 93 "dtd.hash"
+#line 94 "dtd.hash"
       {"input",		0, 1, 1, 0, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""},
-#line 92 "dtd.hash"
+#line 93 "dtd.hash"
       {"img",		0, 1, 1, 0, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 88 "dtd.hash"
+#line 89 "dtd.hash"
       {"head",		0, 0, 0, 0, 0, 1, 1, {"html", NULL}},
-#line 126 "dtd.hash"
+#line 127 "dtd.hash"
       {"thead",		0, 0, 1, 0, 0, 1, 1, {"table", NULL}},
-#line 106 "dtd.hash"
+#line 107 "dtd.hash"
       {"option",		1, 0, 1, 0, 0, 1, 1, {"select", "optgroup", NULL}},
-#line 87 "dtd.hash"
+#line 88 "dtd.hash"
       {"h6",		1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
-#line 94 "dtd.hash"
+#line 95 "dtd.hash"
       {"ins",		1, 0, 1, 1, 0, 0, 0, {"p", "body", "a", "abbr", "acronym", "address", "b", "bdo", "big", "blockquote", "button", "caption", "cite", "code", "colgroup", "dd", "dfn", "div", "dl", "dt", "em", "fieldset", "form", "h1", "h2", "h3", "h4", "h5", "h6", "i", "kbd", "label", "legend", "li", "map", "noscript", "object", "ol", "optgroup", "option", "pre", "q", "samp", "select", "small", "span", "strong", "sub", "sup", "table", "tbody", "td", "textarea", "tfoot", "th", "thead", "tt", "ul", "var", NULL}},
-#line 90 "dtd.hash"
+#line 91 "dtd.hash"
       {"html",		0, 0, 0, 0, 0, 1, 1, {NULL, NULL}},
-#line 64 "dtd.hash"
+#line 65 "dtd.hash"
       {"blockquote",	0, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
-#line 103 "dtd.hash"
+#line 104 "dtd.hash"
       {"object",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "head", "i", "ins", "kbd", "label", "legend", "li", "object", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 130 "dtd.hash"
+#line 131 "dtd.hash"
       {"ul",		0, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
-#line 62 "dtd.hash"
+#line 63 "dtd.hash"
       {"bdo",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 99 "dtd.hash"
-      {"link",		0, 1, 1, 0, 0, 0, 1, {"head", NULL}},
-#line 121 "dtd.hash"
+#line 100 "dtd.hash"
+      {"link",		0, 1, 1, 0, 0, 1, 0, {"head", NULL}},
+#line 122 "dtd.hash"
       {"tbody",		0, 0, 0, 0, 0, 1, 1, {"table", NULL}},
       {""},
-#line 86 "dtd.hash"
+#line 87 "dtd.hash"
       {"h5",		1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
-#line 119 "dtd.hash"
+#line 120 "dtd.hash"
       {"sup",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""}, {""}, {""},
-#line 80 "dtd.hash"
-      {"fieldset",	1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
 #line 81 "dtd.hash"
+      {"fieldset",	1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
+#line 82 "dtd.hash"
       {"form",		0, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "dd", "del", "div", "fieldset", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
       {""}, {""},
-#line 85 "dtd.hash"
+#line 86 "dtd.hash"
       {"h4",		1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
       {""},
-#line 65 "dtd.hash"
+#line 66 "dtd.hash"
       {"body",		0, 0, 0, 0, 0, 1, 1, {"html", NULL}},
       {""}, {""},
-#line 128 "dtd.hash"
+#line 129 "dtd.hash"
       {"tr",		0, 0, 1, 0, 0, 1, 1, {"tbody", "tfoot", "thead", NULL}},
-#line 76 "dtd.hash"
+#line 77 "dtd.hash"
       {"div",		1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
       {""}, {""}, {""},
-#line 84 "dtd.hash"
+#line 85 "dtd.hash"
       {"h3",		1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
-#line 75 "dtd.hash"
+#line 76 "dtd.hash"
       {"dfn",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""}, {""}, {""},
-#line 95 "dtd.hash"
+#line 96 "dtd.hash"
       {"kbd",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 56 "dtd.hash"
+#line 57 "dtd.hash"
       {"abbr",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""},
-#line 83 "dtd.hash"
+#line 84 "dtd.hash"
       {"h2",		1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
-#line 63 "dtd.hash"
+#line 64 "dtd.hash"
       {"big",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""},
-#line 60 "dtd.hash"
+#line 61 "dtd.hash"
       {"b",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""},
-#line 131 "dtd.hash"
+#line 132 "dtd.hash"
       {"var",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""}, {""},
-#line 82 "dtd.hash"
+#line 83 "dtd.hash"
       {"h1",		1, 0, 1, 1, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}},
       {""}, {""}, {""}, {""},
-#line 125 "dtd.hash"
+#line 126 "dtd.hash"
       {"th",		1, 0, 1, 0, 0, 1, 1, {"tr", NULL}},
-#line 118 "dtd.hash"
+#line 119 "dtd.hash"
       {"sub",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
       {""},
-#line 66 "dtd.hash"
+#line 67 "dtd.hash"
       {"br",		0, 1, 1, 0, 0, 0, 1, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "button", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
       {""}, {""}, {""},
-#line 67 "dtd.hash"
+#line 68 "dtd.hash"
       {"button",		1, 0, 1, 1, 0, 0, 0, {"p", "a", "abbr", "acronym", "address", "b", "bdo", "big", "caption", "cite", "code", "dd", "del", "dfn", "div", "dt", "em", "fieldset", "h1", "h2", "h3", "h4", "h5", "h6", "i", "ins", "kbd", "label", "legend", "li", "object", "pre", "q", "samp", "small", "span", "strong", "sub", "sup", "td", "th", "tt", "var", NULL}},
-#line 89 "dtd.hash"
+#line 90 "dtd.hash"
       {"hr",		0, 1, 1, 0, 0, 1, 1, {"body", "blockquote", "button", "dd", "del", "div", "fieldset", "form", "ins", "li", "map", "noscript", "object", "td", "th", NULL}}
     };
 
@@ -361,5 +362,5 @@ lookup_element (str, len)
     }
   return 0;
 }
-#line 132 "dtd.hash"
+#line 133 "dtd.hash"
 
