@@ -9,10 +9,9 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 4 August 2000
- * Version: $Id: genid.c,v 1.13 2013-04-05 19:38:42 bbos Exp $
  **/
 
-#include <config.h>
+#include "config.h"
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
