@@ -6,10 +6,10 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 20 Aug 2000
- * Version: $Id: hxaddid.c,v 1.6 2013-03-23 23:18:09 bbos Exp $
+ * Version: $Id: hxaddid.c,v 1.7 2013-07-25 20:56:53 bbos Exp $
  *
  **/
-#include <config.h>
+#include "config.h"
 #include <assert.h>
 #include <ctype.h>
 #include <stdlib.h>
