@@ -22,7 +22,10 @@
  *
  * The bibliography database must be a refer-style database. Though
  * for the purposes of this program all lines that don't start with
- * "%L" are ignored. Lines with "%L" are assumed to contain a label.
+ * "%L" or %K are ignored. Lines with "%L" are assumed to contain a
+ * label. Lines with %K are assumed to contain whitespace separated
+ * keywords, which are effectively aliases for the label. Entries must
+ * have one %L line and one or zero %K lines.
  *
  * Options:
  *
@@ -63,10 +66,14 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 18 March 2000
- * Version: $Id: hxcite.c,v 1.6 2013-03-23 23:18:09 bbos Exp $
+ * Version: $Id: hxcite.c,v 1.8 2013-10-08 16:46:21 bbos Exp $
  **/
 
-#include <config.h>
+#include "config.h"
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+#include <assert.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <stdio.h>
@@ -103,6 +110,8 @@
 #define LINESIZE 32768
 #define HASHSIZE 4096				/* Size of hash table */
 
+#define WS " \t\r\n\f"				/* Separates %K keywords */
+
 static string base = "";			/* URL of bibilography */
 static string mark = "";			/* Flag after "'[[" */
 static size_t marklen = 0;			/* Length of mark */
@@ -113,12 +122,13 @@ static FILE *aux;
 static bool skip_comments = false; /* Whether to skip [[ inside <!----> */
 
 
-/* label_exists -- check if the label exists in the bibliographic database */
-static bool label_exists(const string label)
+/* get_label -- get the label for the keyword, or NULL */
+static string get_label(const string keyword)
 {
-  ENTRY e = {label, NULL};
+  ENTRY *result, e = {keyword, NULL};
 
-  return hsearch(e, FIND) != NULL;
+  result = hsearch(e, FIND);
+  return result ? (string) result->data : NULL;
 }
 
 
@@ -162,7 +172,7 @@ static void expand_ref(const string label)
 EXPORT void process_line(const string text, const string fname, int lineno,
 			 bool *in_comment)
 {
-  string h = text, p, q, label;
+  string h = text, p, q, label = NULL, key;
   char c;
 
   /* Loop over occurrences of "[[" + mark + label + "]]"
@@ -195,17 +205,17 @@ EXPORT void process_line(const string text, const string fname, int lineno,
     if (marklen == 0 || strncmp(p + 2, mark, marklen) == 0) {
 
       p += 2 + marklen;				/* Skip "[["/"{{" + mark */
-      label = newnstring(p, q - p);		/* Extract the label */
+      key = newnstring(p, q - p);		/* Extract the key */
 
-      if (! valid_label(label)) {		/* Cannot be a label */
+      if (! valid_label(key)) {			/* Cannot be a key */
 	while (h != q) putchar(*(h++));		/* Copy unchanged */
 	putchar(*q); putchar(*(q+1));
-      } else if (! label_exists(label)) {	/* No citation found: warn */
+      } else if (!(label = get_label(key))) {	/* No citation found: warn */
 	while (h != q) putchar(*(h++));		/* Copy unchanged */
 	putchar(*q); putchar(*(q+1));
 	fprintf(stderr, "%s:%d: warning: no bib entry found for %s\n",
-		fname ? fname : (string)"<stdin>", lineno, label);
-      } else if (c == '[') {			/* Label found: expand */
+		fname ? fname : (string)"<stdin>", lineno, key);
+      } else if (c == '[') {			/* Key found: expand */
 	expand_ref(label);			/* Insert full reference */
 	fprintf(aux, "%s\n", label);		/* Store label */
       } else {					/* "{{" so don't expand */
@@ -213,7 +223,7 @@ EXPORT void process_line(const string text, const string fname, int lineno,
 	putchar(*q); putchar(*(q+1));
 	fprintf(aux, "%s\n", label);		/* Store label */
       }
-      dispose(label);
+      dispose(key);
 
     } else {					/* No valid mark */
 
@@ -227,13 +237,35 @@ EXPORT void process_line(const string text, const string fname, int lineno,
 }
 
 
+/* store_labels_and_keywords -- store label in hash table */
+static void store_labels_and_keywords(const string label, const string keys)
+{
+  string label1, h, b;
+  ENTRY entry;
+
+  assert(label);
+  label1 = strtok_r(label, WS, &b);		/* Remove white space */
+  if (!label1) return;				/* Empty label */
+  entry.key = newstring(label1);
+  entry.data = newstring(label1);
+  if (!hsearch(entry, ENTER)) errexit("%s: %s\n", prog, strerror(errno));
+  if (keys) {
+    for (h = strtok_r(keys, WS, &b); h; h = strtok_r(NULL, WS, &b)) {
+      entry.key = newstring(h);
+      entry.data = newstring(label1);
+      if (!hsearch(entry, ENTER)) errexit("%s: %s\n", prog, strerror(errno));
+    }
+  }
+}
+
+
 /* parse_db -- extract all labels from the refer-style database */
 static void parse_db(const string db)
 {
   char line[LINESIZE];
   FILE *f;
-  int e, i;
-  ENTRY entry;
+  int e;
+  string label = NULL, keywords = NULL;
 
   if (!(f = fopen(db,"r"))) errexit("%s: %s: %s\n", prog, db, strerror(errno));
 
@@ -243,15 +275,18 @@ static void parse_db(const string db)
   /* Search for %L lines */
   clearerr(f);
   while (fgets(line, sizeof(line), f)) {
-    if (strncmp(line, "%L ", 3) == 0) {
-      for (i = strlen(line); i > 0 && isspace(line[i-1]); i--) ;
-      if (i > 3) {				/* Ignore empty field */
-	line[i] = '\0';
-	entry.key = newstring(line + 3);
-	if (!hsearch(entry, ENTER)) errexit("%s: %s\n", prog, strerror(errno));
-      }
+    if (line[0] != '%') {	/* We're outside an entry */
+      if (label) store_labels_and_keywords(label, keywords);
+      dispose(label);
+      dispose(keywords);
+    } else if (strncmp(line, "%L ", 3) == 0) {
+      label = newstring(line + 3);
+    } else if (strncmp(line, "%K ", 3) == 0) {
+      keywords = newstring(line + 3);
     }
   }
+  if (label) store_labels_and_keywords(label, keywords);
+
   if ((e = ferror(f))) errexit("%s: %s: %s\n", prog, db, strerror(e));
 
   if (fclose(f) != 0) errexit("%s: %s: %s\n", prog, db, strerror(errno));
@@ -271,28 +306,26 @@ int main(int argc, char *argv[])
   char line[LINESIZE];
   string h, auxfile = NULL, dbfile = NULL, infile = NULL;
   bool in_comment = false;
-  int i, e, lineno;
+  int e, lineno, c;
   FILE *f;
 
   /* Parse command line arguments */
   prog = argv[0];
-  for (i = 1; i < argc && argv[i][0] == '-' && !eq(argv[i], "--"); i++) {
-    switch (argv[i][1]) {
-    case 'b': base = argv[++i]; break;		/* Set base of URL */
-    case 'p': pattern = argv[++i]; break;	/* Form of expanded ref */
-    case 'a': auxfile = argv[++i]; break;	/* Name of auxfile */
-    case 'm': mark = argv[++i]; marklen = strlen(mark); break; /* After "[[" */
+  while ((c = getopt(argc, argv, "b:p:a:m:cv")) != -1) {
+    switch (c) {
+    case 'b': base = optarg; break;		/* Set base of URL */
+    case 'p': pattern = optarg; break;		/* Form of expanded ref */
+    case 'a': auxfile = optarg; break;		/* Name of auxfile */
+    case 'm': mark = optarg; marklen = strlen(mark); break; /* After "[[" */
     case 'c': skip_comments = true; break;	/* Skip [[ in comments */
     case 'v': printf("Version: %s %s\n", PACKAGE, VERSION); return 0;
     default: usage();
     }
   }
-  if (i < argc && eq(argv[i], "--")) i++;
+  if (optind == argc || argc > optind + 2) usage();
 
-  if (i == argc || argc > i + 2) usage();
-
-  dbfile = argv[i++];
-  if (i != argc) infile = argv[i++];
+  dbfile = argv[optind++];
+  if (optind != argc) infile = argv[optind++];
 
   /* Read the labels from the bibliography database */
   parse_db(dbfile);
@@ -320,7 +353,7 @@ int main(int argc, char *argv[])
   lineno = 1;
   while (fgets(line, sizeof(line), f))
     process_line(line, infile, lineno++, &in_comment);
-  if ((e = ferror(f))) errexit("%s: %s: %s\n", prog, argv[i], strerror(e));
+  if ((e = ferror(f))) errexit("%s: %s\n", prog, strerror(e));
 
   fclose(f);
   fclose(aux);
