@@ -20,7 +20,7 @@
  * See http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231
  */
 
-#include <config.h>
+#include "config.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <assert.h>
