@@ -10,9 +10,9 @@
  *
  * Bert Bos
  * Created Nov 1998
- * $Id: hxcount.c,v 1.3 2013-03-23 23:18:09 bbos Exp $
+ * $Id: hxcount.c,v 1.4 2013-07-25 21:00:38 bbos Exp $
  */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
