@@ -19,10 +19,10 @@
  *
  * Author: Bert Bos
  * Created: 2 Dec 1998
- * Version: $Id: hxincl.c,v 1.12 2013-03-23 23:18:09 bbos Exp $
+ * Version: $Id: hxincl.c,v 1.13 2013-07-25 21:02:59 bbos Exp $
  *
  **/
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
