@@ -40,10 +40,10 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 11 Apr 2000
- * Version: $Id: hxindex.c,v 1.18 2013-03-23 23:18:09 bbos Exp $
+ * Version: $Id: hxindex.c,v 1.20 2013-07-25 21:04:05 bbos Exp $
  *
  **/
-#include <config.h>
+#include "config.h"
 #include <assert.h>
 #include <locale.h>
 #include <wchar.h>
@@ -211,6 +211,7 @@ static void trim(string s)
   string t;
   int i, j;
 
+  if (!s) return;
   t = newstring(s);
   for (i = 0; isspace(t[i]); i++); /* Skip leading white space */
   for (j = 0; t[i]; i++)
