@@ -67,12 +67,15 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 19 March 2000
- * Version: $Id: hxmkbib.c,v 1.4 2013-03-23 23:18:09 bbos Exp $
+ * Version: $Id: hxmkbib.c,v 1.5 2013-07-25 21:05:13 bbos Exp $
  **/
-#include <config.h>
+#include "config.h"
 #ifdef HAVE_ERRNO_H
 #  include <errno.h>
 #endif
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
 #include <stdio.h>
 #if STDC_HEADERS
 # include <string.h>
@@ -480,35 +483,34 @@ int main(int argc, char *argv[])
   string auxfile = NULL, pattern, inputfile = NULL, dbfile, h;
   string *keys = NULL;
   FILE *f, *db, *aux;
-  int i, n;
+  int c, n;
 
   /* Parse command line */
   prog = argv[0];
-  for (i = 1; i < argc && argv[i][0] == '-' && !eq(argv[i], "--"); i++) {
-    switch (argv[i][1]) {
-    case 'a': auxfile = argv[++i]; break;
-    case 's': separator = argv[++i]; break;
-    case 'n': et_al_limit = atoi(argv[++i]); break;
-    case 'r': et_al = argv[++i]; break;
+  while ((c = getopt(argc, argv, "a:s:n:r:")) != -1) {
+    switch (c) {
+    case 'a': auxfile = optarg; break;
+    case 's': separator = optarg; break;
+    case 'n': et_al_limit = atoi(optarg); break;
+    case 'r': et_al = optarg; break;
     default: usage();
     }
   }
-  if (i < argc && eq(argv[i], "--")) i++;
-  if (i == argc || argc > i + 2) usage();
+  if (optind == argc || argc > optind + 2) usage();
 
   /* First argument is refer database */
-  dbfile = argv[i++];
+  dbfile = argv[optind++];
 
   /* Optional second argument is input file */
-  if (i != argc) inputfile = argv[i];
+  if (optind != argc) inputfile = argv[optind];
 
   /* If we don't have an explicit auxfile yet, derive its name */
   if (! auxfile) {
     if (! inputfile) {
       auxfile = "aux.aux";
     } else {
-      newarray(auxfile, strlen(argv[i]) + 5);
-      strcpy(auxfile, argv[i]);
+      newarray(auxfile, strlen(argv[optind]) + 5);
+      strcpy(auxfile, argv[optind]);
       if ((h = strrchr(auxfile, '.'))) *h = '\0';
       strcat(auxfile, ".aux");
     }
