@@ -6,9 +6,9 @@
  *
  * Created 9 May 1998
  * Bert Bos <bert@w3.org>
- * $Id: hxnormalize.c,v 1.15 2013-03-23 23:18:09 bbos Exp $
+ * $Id: hxnormalize.c,v 1.16 2013-07-25 21:08:00 bbos Exp $
  */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <ctype.h>
 #include <stdlib.h>
