@@ -8,9 +8,9 @@
  *
  * Bert Bos
  * Created Sep 1997
- * $Id: hxnum.c,v 1.5 2011/08/26 20:41:01 bbos Exp $
+ * $Id: hxnum.c,v 1.10 2013-07-27 11:58:24 bbos Exp $
  */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
@@ -40,6 +40,7 @@
 
 #define SECNO "secno"				/* class attribute */
 #define NO_NUM "no-num"				/* class-attribute */
+#define OPTS ":l:h:n:1:2:3:4:5:6:?"		/* Command line options */
 
 static int h[] = {-1, 0, 0, 0, 0, 0, 0};	/* Counters for each level */
 static int low = 1;				/* First counter to use */
@@ -245,7 +246,7 @@ static void help(void)
 
 int main(int argc, char *argv[])
 {
-  int i, status = 200;
+  int i, status = 200, c;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -260,43 +261,51 @@ int main(int argc, char *argv[])
   set_endtag_handler(handle_endtag);
 
   /* First find -l and -h */
-  for (i = 1; i < argc && argv[i][0] == '-' && !eq(argv[i], "--"); i++) {
-    switch (argv[i][1]) {
-      case 'l': low = atoi(argv[++i]); break;
-      case 'h': high = atoi(argv[++i]); break;
-      default: ;
+  while ((c = getopt(argc, argv, OPTS)) != -1) {
+    switch (c) {
+    case 'l': low = atoi(optarg); break;
+    case 'h': high = atoi(optarg); break;
+    default: /* skip */;
     }
   }
+  if (low < 1 || low > 6 || high < 1 || high > 6) usage(argv[0]);
+
+#ifdef HAVE_GETOPT_OPTRESET
+  optreset = 1;
+#else
+  optind = 1;
+#endif
+
   /* If -l and/or -h have been set, the default formats are different */
   if (low != 1 || high != 6) {
     for (i = high; i >= low; i--) format[i] = format[i-low+1];
     for (i = high + 1; i <= 6; i++) format[i] = "";
   }
+
   /* Then treat other options */
-  for (i = 1; i < argc && argv[i][0] == '-' && !eq(argv[i], "--"); i++) {
-    switch (argv[i][1]) {
-      case 'l': i++; break;			/* Already handled */
-      case 'h': i++; break;			/* Already handled */
-      case 'n': h[low] = atoi(argv[++i]) - 1; break;
-      case '1': format[1] = argv[++i]; break;
-      case '2': format[2] = argv[++i]; break;
-      case '3': format[3] = argv[++i]; break;
-      case '4': format[4] = argv[++i]; break;
-      case '5': format[5] = argv[++i]; break;
-      case '6': format[6] = argv[++i]; break;
-      case '?': help(); break;
-      default: usage(argv[0]);
+  while ((c = getopt(argc, argv, OPTS)) != -1) {
+    switch (c) {
+    case 'l': break;		/* Already handled */
+    case 'h': break;		/* Already handled */
+    case 'n': h[low] = atoi(optarg) - 1; break;
+    case '1': format[1] = optarg; break;
+    case '2': format[2] = optarg; break;
+    case '3': format[3] = optarg; break;
+    case '4': format[4] = optarg; break;
+    case '5': format[5] = optarg; break;
+    case '6': format[6] = optarg; break;
+    case '?': help(); break;
+    default: usage(argv[0]);
     }
   }
-  if (i < argc && eq(argv[i], "--")) i++;
 
-  if (i == argc) yyin = stdin;
-  else if (i == argc - 1 && eq(argv[i], "-")) yyin = stdin;
-  else if (i == argc - 1) yyin = fopenurl(argv[i], "r", &status);
+  if (optind == argc) yyin = stdin;
+  else if (optind == argc - 1 && eq(argv[optind], "-")) yyin = stdin;
+  else if (optind == argc - 1) yyin = fopenurl(argv[optind], "r", &status);
   else usage(argv[0]);
 
-  if (yyin == NULL) {perror(argv[i]); exit(1);}
-  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
+  if (yyin == NULL) {perror(argv[optind]); exit(1);}
+  if (status != 200) errexit("%s : %s\n", argv[optind], http_strerror(status));
 
   if (yyparse() != 0) {
     exit(3);
