@@ -6,11 +6,11 @@
  *
  * Bert Bos <bert@w3.org>
  * Created Feb 2000
- * $Id: hxprune.c,v 1.6 2013-03-23 23:18:09 bbos Exp $
+ * $Id: hxprune.c,v 1.7 2013-07-25 21:11:49 bbos Exp $
  *
  **/
 /* #include <mcheck.h> */
-#include <config.h>
+#include "config.h"
 #include <assert.h>
 #include <ctype.h>
 #include <stdlib.h>
