@@ -39,10 +39,10 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 5 Jul 2001
- * Version: $Id: hxselect.c,v 1.6 2013-03-23 23:18:10 bbos Exp $
+ * Version: $Id: hxselect.c,v 1.7 2013-06-30 20:43:31 bbos Exp $
  *
  **/
-#include <config.h>
+#include "config.h"
 #include <assert.h>
 #include <ctype.h>
 #include <stdlib.h>
