@@ -23,10 +23,10 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created Sep 1997
- * Version: $Id: hxtoc.c,v 1.8 2013-04-19 13:10:43 bbos Exp $
+ * Version: $Id: hxtoc.c,v 1.9 2013-06-30 20:40:57 bbos Exp $
  *
  **/
-#include <config.h>
+#include "config.h"
 #include <assert.h>
 #include <ctype.h>
 #include <stdlib.h>
