@@ -61,8 +61,8 @@ static void expand(const char *s)
       for (i++, n = 0; isalnum(s[i+n]); n++) ;
       if (! (e = lookup_entity(s + i, n))) {	/* Unknown entity */
 	if (fix_ampersands) fputs("&amp;", stdout); else putchar('&');
-      } else if (leave_builtin && (e->code == 38 || e->code == 60
-	  || e->code == 62 || e->code == 34)) {	/* Keep it */
+      } else if (leave_builtin && (e->code == 38 || e->code == 39
+ 	  || e->code == 60 || e->code == 62 || e->code == 34)) { /* Keep it */
 	putchar('&');
 	for (; isalnum(s[i]); i++) putchar(s[i]);
 	if (s[i] != ';') putchar(';');		/* Make sure the ; is there */
