@@ -11,10 +11,10 @@
  *
  * Author: Bert Bos
  * Created: 8 November 2005
- * Version: $Id: hxunxmlns.c,v 1.5 2013-03-23 23:18:10 bbos Exp $
+ * Version: $Id: hxunxmlns.c,v 1.6 2013-06-30 20:39:10 bbos Exp $
  *
  **/
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
