@@ -11,10 +11,10 @@
  *
  * Author: Bert Bos
  * Created: 22 Mar 2000
- * Version: $Id: hxxmlns.c,v 1.6 2013-03-23 23:18:10 bbos Exp $
+ * Version: $Id: hxxmlns.c,v 1.7 2013-06-30 20:37:30 bbos Exp $
  *
  **/
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
