@@ -505,7 +505,7 @@ static FILE *open_http2(const conststring machine, const conststring port,
 			const conststring path, Dictionary request,
 			Dictionary response, int maxredirs, int *status)
 {
-  Boolean delete_response = !response;
+  int delete_response = !response;
   conststring h, v;
   char buf[BUFLEN];
   int fd, n, i;
