@@ -13,10 +13,10 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 8 July 2001
- * Version: $Id: selector.c,v 1.9 2013-03-23 23:18:10 bbos Exp $
+ * Version: $Id: selector.c,v 1.10 2013-06-30 20:32:48 bbos Exp $
  **/
 
-#include <config.h>
+#include "config.h"
 #include <assert.h>
 #include <stdlib.h>
 #include <stdio.h>
