@@ -4,9 +4,9 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 31 Mar 2000
- * Version: $Id: strdup.c,v 1.2 2007/10/23 11:17:08 bbos Exp $
+ * Version: $Id: strdup.c,v 1.3 2013-06-30 20:32:24 bbos Exp $
  **/
-#include <config.h>
+#include "config.h"
 #include <stdlib.h>
 #include "export.h"
 
