@@ -1,8 +1,8 @@
 :
 trap 'rm $TMP1 $TMP2 $TMP3' 0
-TMP1=`mktemp` || exit 1
-TMP2=`mktemp` || exit 1
-TMP3=`mktemp` || exit 1
+TMP1=`mktemp /tmp/tmp.XXXXXXXXXX` || exit 1
+TMP2=`mktemp /tmp/tmp.XXXXXXXXXX` || exit 1
+TMP3=`mktemp /tmp/tmp.XXXXXXXXXX` || exit 1
 
 cat >$TMP1 <<-EOF
 	<a href="foo/bar">.</a>
