@@ -4,11 +4,13 @@
  * Copyright  1994-2000 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
+ * To do: count characters, not bytes
+ *
  * Bert Bos
  * Created 10 May 1998
- * $Id: textwrap.c,v 1.26 2013-03-23 23:18:10 bbos Exp $
+ * $Id: textwrap.c,v 1.28 2013-07-25 20:13:57 bbos Exp $
  */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <ctype.h>
 #include <assert.h>
