@@ -5,7 +5,7 @@
  * Author: Bert Bos <bert@w3.org>
  * Created: 1997
  **/
-#include <config.h>
+#include "config.h"
 #include <stdlib.h>
 #include <stdarg.h>
 #ifdef HAVE_STRING_H
